@@ -33,7 +33,7 @@ class JavascriptParser(LanguageParser):
         
         docstring = ''
         if docstring_node:
-            docstring = strip_c_style_comment_delimiters(match_from_span(docstring_node[0], blob))
+            docstring = match_from_span(docstring_node[0], blob)
         return docstring
     
     @staticmethod
@@ -45,13 +45,21 @@ class JavascriptParser(LanguageParser):
     @staticmethod
     def get_function_list(node):
         res = []
-        traverse_type(node, res, ['function_declaration', 'method_definition'])
+        traverse_type(node, res, ['function_declaration', 'function', 'method_definition', 'generator_function_declaration'])
+        for node in res[:]:
+            if not node.children:
+                res.remove(node)
+
         return res
     
     @staticmethod
     def get_class_list(node):
         res = []
-        traverse_type(node, res, ['class_declaration'])
+        traverse_type(node, res, ['class_declaration', 'class'])
+        for node in res[:]:
+            if not node.children:
+                res.remove(node)
+
         return res
 
     @staticmethod
